pub fn evaluate(
store: &ObjectStore,
labels: &[Label],
match_threshold: f64,
) -> Result<EvalReport, VasariError>Expand description
Evaluate vasari why over a labeled corpus already ingested into store.
pub fn evaluate(
store: &ObjectStore,
labels: &[Label],
match_threshold: f64,
) -> Result<EvalReport, VasariError>Evaluate vasari why over a labeled corpus already ingested into store.